searchData={"items":[{"type":"module","title":"Cid","doc":"Shortcut module for ContextID.","ref":"Cid.html"},{"type":"function","title":"Cid.generate_id/2","doc":"","ref":"Cid.html#generate_id/2"},{"type":"module","title":"ContextID","doc":"A module for generating custom identifiers.","ref":"ContextID.html"},{"type":"function","title":"ContextID.default_length/0","doc":"Gets the default length for generated identifiers.\n\nThe default length is used when no length is provided during ID generation.","ref":"ContextID.html#default_length/0"},{"type":"function","title":"ContextID.default_prefix/0","doc":"Gets the default prefix for generated identifiers.\n\nThe default prefix is used when no prefix is provided during ID generation.","ref":"ContextID.html#default_prefix/0"},{"type":"function","title":"ContextID.generate_id/2","doc":"Generates a custom identifier with a specified `prefix` and of a specified `length`.","ref":"ContextID.html#generate_id/2"},{"type":"extras","title":"README","doc":"#","ref":"readme.html"},{"type":"extras","title":"README.md Template for ContextID - README","doc":"# ContextID","ref":"readme.html#readme-md-template-for-contextid"},{"type":"extras","title":"Introduction - README","doc":"ContextID is an Elixir package that provides a simple yet flexible way to generate custom, context-rich identifiers. It allows users to specify a custom prefix for IDs, enhancing readability and making them more meaningful in various applications, you get similar uniqueness to a uuidv4 but now with an element of context at the front given your prefix.","ref":"readme.html#introduction"},{"type":"extras","title":"Examples - README","doc":"Here are some sample IDs that your package could generate with various prefixes and lengths:\n\n1. With prefix `acct` and a length of 8 bytes: `acct_9b545ad85399e20e`\n2. With prefix `id` and a length of 16 bytes: `id_a53eb7a0ccfda31b1df4776ba1b11124`\n3. With prefix `acct_number` and a length of 4 bytes: `acct_number_3b63b3bc`\n\nThese examples are simply meant to illustrate the flexibility and utility of the `ContextID` package in generating readable, context-specific identifiers.","ref":"readme.html#examples"},{"type":"extras","title":"Features - README","doc":"- **Custom Prefixes for IDs**: Generate IDs with user-defined prefixes, enhancing readability and context awareness.\n- **Configurable ID Length**: Tailor the length of your generated IDs to suit your specific requirements.\n- **Streamlined Usage**: Offers a straightforward and user-friendly interface, making it easy to integrate and use in any Elixir project.\n- **No External Dependencies**: Built exclusively using Elixir's standard library, ensuring a lightweight and efficient solution without the need for additional dependencies.","ref":"readme.html#features"},{"type":"extras","title":"Installation - README","doc":"Add `contextual_id` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:contextual_id, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - README","doc":"Generating a custom ID is straightforward:\n\n```elixir\n# Using the main module\nid = ContextID.generate_id(\"prefix\", 16)\n\n# Using the shortcut alias\nid = Cid.generate_id(\"prefix\", 16)\n```","ref":"readme.html#usage"},{"type":"extras","title":"Examples - README","doc":"Generate an ID with a custom prefix:\n\n```elixir\nContextID.generate_id(\"user\", 10)\n# => \"user_18165fe7c154341e861c\"\n```\n\nGenerate an ID with the default settings:\n\n```elixir\nCid.generate_id()\n# => \"id_a53eb7a0ccfda31b1df4776ba1b11124\"\n```","ref":"readme.html#examples"},{"type":"extras","title":"Configuration - README","doc":"`ContextID` allows for global configuration of default prefix and ID length, which can be set for your entire Elixir application. This means you can specify default values for these parameters, and `ContextID` will use them whenever you generate an ID without explicitly providing these arguments.\n\nTo set up global configuration, add the following lines to your application's configuration file (typically found at `config/config.exs`):\n\n```elixir\n# In config/config.exs\nconfig :contextual_id, :default_prefix, \"your_default_prefix\"\nconfig :contextual_id, :default_length, your_default_length\n```\n\nReplace `\"your_default_prefix\"` with the default prefix string you wish to use, and `your_default_length` with the default length (as an integer) for the IDs.\n\nFor example, setting:\n\n```elixir\nconfig :contextual_id, :default_prefix, \"acct\"\nconfig :contextual_id, :default_length, 12\n```\n\nmeans that `ContextID.generate_id()` will produce IDs like `\"acct_1a2b3c4d5e6f7a8b9c0d\"` by default, unless you specify different arguments when calling the function.\n\nThis feature adds a layer of convenience and customization, allowing you to set and forget these defaults as per your application's needs.","ref":"readme.html#configuration"},{"type":"extras","title":"Contributing - README","doc":"Contributions are welcome! Please read our [Contributing Guidelines](CONTRIBUTING.md) for details on how to submit pull requests, file issues, and so on.","ref":"readme.html#contributing"},{"type":"extras","title":"Testing - README","doc":"Run the test suite with:\n\n```shell\nmix test\n```","ref":"readme.html#testing"},{"type":"extras","title":"License - README","doc":"ContextID is released under the [MIT License](LICENSE).","ref":"readme.html#license"},{"type":"extras","title":"Acknowledgments - README","doc":"- None yet","ref":"readme.html#acknowledgments"},{"type":"extras","title":"Contact - README","doc":"For any questions or suggestions, please open an issue in the GitHub repository.","ref":"readme.html#contact"}],"content_type":"text/markdown"}